package model;


import javafx.beans.property.DoubleProperty;
import javafx.beans.property.SimpleDoubleProperty;
import javafx.beans.property.SimpleStringProperty;
import javafx.beans.property.StringProperty;
import javafx.collections.*;
import java.util.*;
import static model.Captor.rand;

public class CapteurVirtuel extends Sujet{

    private final UUID id= UUID.randomUUID();
    private final StringProperty nom;
    private final DoubleProperty tempMoyenne = new SimpleDoubleProperty(0);

    final Map<Integer, Captor> source = new HashMap<>();
    private final ObservableMap<Integer,Captor> lesCapteurs = FXCollections.observableMap(source);
    public CapteurVirtuel(String nom){
        this.nom= new SimpleStringProperty(nom);
        this.tempMoyenne.set(0.0);
        lesCapteurs.addListener((MapChangeListener<? super Integer, ? super Captor>) c -> {
            this.tempMoyenne.set(this.updateData());
            System.out.println("HEY");
        });
    }

    public UUID getId()
    {
        return this.id;
    }

    public String getName(){
        return this.nom.get();
    }

    public DoubleProperty getTempMoyenneProperty(){
        return this.tempMoyenne;
    }

    public Double getTempMoyenne(){
        return this.tempMoyenne.get();
    }

    public boolean isNegative(){
        return (this.getTempMoyenne()<0);
    }

    public boolean isHot(){
        return (this.getTempMoyenne()>30);
    }

    @Override
    public String toString(){
        return Double.toString(this.getTempMoyenne());
    }


    public Collection<Captor> getLesCapteurs(){
        return lesCapteurs.values();
    }

    public void addToLesCapteurs(Captor c){
        lesCapteurs.put((rand.nextInt()%10),c);
    }

    private Double updateData() {
        int coef = 0;
        double valeurs =0;
        for (Map.Entry<Integer, Captor> entry : lesCapteurs.entrySet()){
            coef += entry.getKey();
            valeurs += entry.getKey() * entry.getValue().getTemperature();
        }
        if (coef==0 || valeurs==0){
            return 0.0;
        }else {
            return valeurs / coef;
        }
    }

}
